package com.bwie.auth.controller;

import com.bwie.auth.service.impl.AuthServiceImpl;
import com.bwie.common.domain.request.LoginRequest;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

@RestController
@Log4j2
public class AuthController {
    @Autowired
    private AuthServiceImpl authService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 登录
     * @param loginRequest
     * @return
     */
    @PostMapping("login")
    public Result<JwtResponse> login(@RequestBody LoginRequest loginRequest){
        log.info("功能：登录，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),loginRequest);

        Result<JwtResponse> result = authService.login(loginRequest);

        log.info("功能：登录，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 获取当前用户信息
     * @return
     */
    @GetMapping("getInfo")
    public Result<UserResponse> getInfo(){
        log.info("功能：获取当前用户信息，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),"");

        Result<UserResponse> result = authService.getInfo();

        log.info("功能：获取当前用户信息，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }


    /**
     * 登出
     * @return
     */
    @PostMapping("logout")
    public Result logout(){
        log.info("功能：登出，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),"");

        Result result = authService.logout();

        log.info("功能：登出，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }
}
