package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.UserFeignService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.request.LoginRequest;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import io.jsonwebtoken.Jwt;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeignService userFeignService;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Autowired
    private HttpServletRequest request;

    /**
     * 登录
     * @param loginRequest
     * @return
     */
    @Override
    public Result<JwtResponse> login(LoginRequest loginRequest) {
        //非空验证
        if (StringUtils.isAnyBlank(loginRequest.getUserName(),loginRequest.getPassword())){
            return Result.error("账号密码不能为空");
        }
        Result<UserResponse> byUserName = userFeignService.findByUserName(loginRequest.getUserName());
        UserResponse user = byUserName.getData();
        //判断用户是否存在
        if (user==null){
            return Result.error("账号未注册");
        }
        //判断密码是否正确
        if (!user.getPassword().equals(loginRequest.getPassword())){
            return Result.error("账号密码错误");
        }
        //登录成功 生成token 用户数据存入redis
        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY,userKey);
        map.put(JwtConstants.DETAILS_USER_ID,user.getId());
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey,
                JSON.toJSONString(user),60, TimeUnit.MINUTES);
        //生成jwt
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setExpire("60Min");
        return Result.success(jwtResponse);
    }

    /**
     * 获取用户信息
     * @return
     */
    @Override
    public Result<UserResponse> getInfo() {
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        UserResponse userResponse = JSON.parseObject(s, UserResponse.class);
        return Result.success(userResponse);
    }

    /**
     * 登出
     * @return
     */
    @Override
    public Result logout() {
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        redisTemplate.delete(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        return Result.success();
    }
}
