package com.bwie.gateway.filters;

import com.bwie.common.constants.TokenConstants;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import com.bwie.gateway.config.IgnoreWhiteConfig;
import com.bwie.gateway.utils.GatewayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilter;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.core.Ordered;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

import java.util.List;
import java.util.concurrent.TimeUnit;

@Component
public class MyFilter implements Ordered, GatewayFilter {
    @Autowired
    private IgnoreWhiteConfig ignoreWhiteConfig;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {
        //获取白名单
        List<String> whites = ignoreWhiteConfig.getWhites();
        ServerHttpRequest request = exchange.getRequest();
        //验证路径是否在白名单中
        if (StringUtils.matches(request.getURI().getPath(),whites)){
            return chain.filter(exchange);
        }
        //token非空验证
        String token = request.getHeaders().getFirst("token");
        if (StringUtils.isEmpty(token)){
            return GatewayUtils.errorResponse(exchange,"token不能为空");
        }
        //token合法性验证
        try {
            JwtUtils.parseToken(token);
        } catch (Exception exception) {
            return GatewayUtils.errorResponse(exchange,"token格式错误");
        }
        //token有效性验证
        String userKey = JwtUtils.getUserKey(token);
        if (!redisTemplate.hasKey(TokenConstants.LOGIN_TOKEN_KEY+userKey)){
            return GatewayUtils.errorResponse(exchange,"token过期");
        }
        //续期
        redisTemplate.expire(TokenConstants.LOGIN_TOKEN_KEY+userKey,15, TimeUnit.MINUTES);
        return chain.filter(exchange);
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
