package com.bwie.es.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.domain.response.Loan;
import com.bwie.common.result.Result;
import com.bwie.es.feign.LoanFeignService;
import com.bwie.es.service.EsService;
import org.elasticsearch.action.bulk.BulkRequest;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.common.xcontent.XContentType;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Service
public class EsServiceImpl implements EsService {
    @Autowired
    private LoanFeignService loanFeignService;

    @Resource
    private RestHighLevelClient restHighLevelClient;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;


    private static final String INDEX_NAME="loan";

    /**
     * 借款数据同步es
     * @return
     */
    @Override
    public Result dataToEs() {
        try {
            BulkRequest bulkRequest = new BulkRequest(INDEX_NAME);
            Result<List<Loan>> listResult = loanFeignService.loanData();
            List<Loan> list = listResult.getData();
            for (Loan loan : list) {
                bulkRequest.add(new IndexRequest().
                        id(loan.getId().toString()).
                        source(JSON.toJSONString(loan), XContentType.JSON));
            }
            restHighLevelClient.bulk(bulkRequest, RequestOptions.DEFAULT);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return Result.success();
    }

    /**
     * 借款列表
     * @return
     */
    @Override
    public Result<List<Loan>> loanDataList() {
        ArrayList<Loan> loans = new ArrayList<>();
        try {
            this.dataToEs();
            SearchRequest searchRequest = new SearchRequest(INDEX_NAME);
            SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
            BoolQueryBuilder boolQuery = QueryBuilders.boolQuery();
            searchSourceBuilder.query(boolQuery);
            searchRequest.source(searchSourceBuilder);
            SearchResponse search = restHighLevelClient.search(searchRequest, RequestOptions.DEFAULT);
            SearchHit[] hits = search.getHits().getHits();
            for (SearchHit hit : hits) {
                String sourceAsString = hit.getSourceAsString();
                Loan loan = JSON.parseObject(sourceAsString, Loan.class);
                loans.add(loan);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return Result.success(loans);
    }
}
