package com.bwie.loan.config;

import com.bwie.common.domain.response.Loan;
import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import com.bwie.loan.feign.UserFeignService;
import com.bwie.loan.service.impl.LoanServiceImpl;
import com.rabbitmq.client.Channel;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;

import java.util.Date;
import java.util.HashMap;

@Configuration
public class ProductConfig {
    @Autowired
    private LoanServiceImpl loanService;

    @Autowired
    private UserFeignService userFeignService;


    @RabbitListener(queuesToDeclare = @Queue("ONE_QUEUE"))
    public void productMsg(String msg, Message message, Channel channel){
        //异步发送短信确保数据不会因发送过程而丢失 根据id获取借款申请人
        Loan loan = loanService.findLoanById(Integer.valueOf(msg));
        //如果20分钟内没有抢单操作，系统应发送短信通知借款人，并将借款状态改为未放款（3分）
        if (new Date().getTime()-loan.getCreateTime().getTime()>20*60*10000 && loan.getStatus()==0){
            //根据用户id获取用户手机号 发送短信
            Result<UserResponse> byUserId = userFeignService.findByUserId(msg);
            String phone = byUserId.getData().getPhone();
            com.bawei.common.utils.TelSmsUtils.sendSms(phone,"SMS100001"
                    ,new HashMap<String, String>(){{
                        put("msg","未放款");
                    }});
            //修改状态
            loanService.updateStatus(msg,3);
        }

    }
}
