package com.bwie.loan.controller;

import com.bwie.common.domain.request.LoanRequest;
import com.bwie.common.domain.response.Loan;
import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import com.bwie.loan.service.impl.LoanServiceImpl;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Log4j2
public class LoanController {

    @Autowired
    private LoanServiceImpl loanService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 借款数据
     * @return
     */
    @GetMapping("loanData")
    public Result<List<Loan>> loanData(){
        log.info("功能：借款数据，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),"");

        Result<List<Loan>> result = loanService.loanData();

        log.info("功能：借款数据，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 借款
     * @param loanRequest
     * @return
     */
    @PostMapping("insertLoan")
    public Result insertLoan(@RequestBody LoanRequest loanRequest){
        log.info("功能：借款，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),loanRequest);

        Result result = loanService.insertLoan(loanRequest);

        log.info("功能：借款，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }
}
