package com.bwie.loan.controller;

import com.bwie.common.domain.Repayment;
import com.bwie.common.domain.response.Loan;
import com.bwie.common.result.Result;
import com.bwie.loan.service.impl.LoanServiceImpl;
import com.bwie.loan.service.impl.RepaymentServiceImpl;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Log4j2
public class RepaymentController {

    @Autowired
    private RepaymentServiceImpl repaymentService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 根据借款id查询借款计划
     * @return
     */
    @GetMapping("/repaymentListByLoanId/{loanId}")
    public Result<List<Repayment>> repaymentListByLoanId(@PathVariable Integer loanId){
        log.info("功能：根据借款id查询借款计划，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),loanId);

        Result<List<Repayment>> result = repaymentService.repaymentListByLoanId(loanId);

        log.info("功能：根据借款id查询借款计划，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 提前还款
     * @param repayment
     * @return
     */
    @PostMapping("prepayment")
    public Result prepayment(@RequestBody Repayment repayment){
        log.info("功能：提前还款，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),repayment);

        Result result = repaymentService.prepayment(repayment);

        log.info("功能：提前还款，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 添加还款计划/抢单
     * @param loan
     * @return
     */
    @PostMapping("insertRepayment")
    public Result insertRepayment(@RequestBody Loan loan){
        log.info("功能：添加还款计划，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),loan);

        Result result = repaymentService.insertRepayment(loan);

        log.info("功能：添加还款计划，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }
}
