package com.bwie.loan.service.impl;

import cn.hutool.core.io.unit.DataUnit;
import com.bwie.common.domain.Repayment;
import com.bwie.common.domain.response.Loan;
import com.bwie.common.result.Result;
import com.bwie.loan.mapper.RepaymentMapper;
import com.bwie.loan.service.RepaymentService;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.assertj.core.util.DateUtil;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

@Service
public class RepaymentServiceImpl implements RepaymentService {
    @Autowired
    private RepaymentMapper repaymentMapper;

    @Autowired
    private LoanServiceImpl loanService;

    /**
     * 根据借款id查询借款计划
     * @return
     */
    @Override
    public Result<List<Repayment>> repaymentListByLoanId(Integer loanId) {
        List<Repayment> list = repaymentMapper.repaymentListByLoanId(loanId);
        return Result.success(list);
    }

    /**
     * 提前还款
     * @param repayment
     * @return
     */
    @Override
    public Result prepayment(Repayment repayment) {
        //提前还款不需要支付手续费
        //获取正常还款时间
        long time = repayment.getRepaymentDate().getTime();
        //获取现在时间
        long nowTime = new Date().getTime();
        //相差天数
        int day = (int) ((time-nowTime)/(60*1000*60*24));
        //获取当前借款
        Loan loan = loanService.findLoanById(repayment.getLoanId());
        //减去的手续费
        double money = loan.getLoanAmount()*loan.getLoanInterest()*day*0.01;
        //最终本期支付的金额
        repayment.setRepaymentAmount(repayment.getRepaymentAmount()-money);
        //修改本条还款计划金额及状态
        repaymentMapper.updateRepay(repayment);
        return Result.success();
    }

    /**
     * 添加还款计划/抢单
     * @param loan
     * @return
     */
    @Override
    @Transactional
    public Result insertRepayment(Loan loan) {
        //修改借款状态
        loanService.updateStatus(loan.getId().toString(),1);
        //添加还款计划
        Integer periods = loan.getPeriods();
        Repayment repayment = new Repayment();
        //还款金额 每月还本付息金额=（本金/还款月数）+（本金-累计已还本金）×月利率
        double avgMoney = loan.getLoanAmount()/periods;
        double avgInterest = loan.getLoanAmount()*loan.getLoanInterest()*30*0.01;
        repayment.setRepaymentAmount(avgMoney);
        //本期利息
        repayment.setCurrentProfit(avgInterest);
        //有几期添加几期
        for (int i = 1; i <= periods; i++) {
            repayment.setLoanId(loan.getId());
            repayment.setPeriod(i);
            //每期还款时间
            Date createTime = loan.getCreateTime();
            Date date = DateUtils.addMonths(createTime, 1);
            repayment.setRepaymentDate(date);
            repaymentMapper.insertRepayment(repayment);
        }

        return Result.success();
    }


}
