package com.bwie.system.controller;

import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import com.bwie.system.service.impl.UserServiceImpl;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

@RestController
@Log4j2
public class UserController {

    @Autowired
    private UserServiceImpl userService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 根据用户名查找用户
     * @param userName
     * @return
     */
    @GetMapping("/findByUserName/{userName}")
    public Result<UserResponse> findByUserName(@PathVariable String userName){
        log.info("功能：根据用户名查找用户，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),userName);

        Result<UserResponse> result = userService.findByUserName(userName);

        log.info("功能：根据用户名查找用户，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 根据用户id查找用户
     * @param id
     * @return
     */
    @GetMapping("/findByUserId/{id}")
    public Result<UserResponse> findByUserId(@PathVariable String id){
        log.info("功能：根据用户id查找用户，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),id);

        Result<UserResponse> result = userService.findByUserId(id);

        log.info("功能：根据用户id查找用户，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }
}
